@@ -19,53 +19,62 @@ X or Y axis for OFC2.
 
 use Moose;
 use Moose::Util::TypeConstraints;
+use MooseX::StrictConstructor;
 
 our $VERSION = '0.01';
 
+use Chart::OFC2;
 use Chart::OFC2::Labels;
 
 
 =head1 PROPERTIES
 
-    subtype 'Chart-OFC2-YAxis'
+    subtype 'Chart.OFC2.YAxis'
         => as 'Object'
         => where { $_[0]->isa('Chart::OFC2::YAxis') };
-    subtype 'Chart-OFC2-XAxis' 
+    subtype 'Chart.OFC2.XAxis' 
         => as 'Object'
         => where { $_[0]->isa('Chart::OFC2::XAxis') };
 
-    has 'name'   => ( is => 'rw', isa => enum(['x_axis', 'y_axis', 'y_axis_right']), required => 1 );
-    has 'labels' => ( is => 'rw', isa => 'Chart-OFC2-Labels', coerce  => 1);
-    has 'stroke' => ( is => 'rw', isa => 'Int', );
-    has 'color' => ( is => 'rw', isa => 'Str',  );
-    has 'offset' => ( is => 'rw', isa => 'Bool', );
-    has 'grid_color' => ( is => 'rw', isa => 'Str', );
-    has '3d' => ( is => 'rw', isa => 'Bool', );
-    has 'steps' => ( is => 'rw', isa => 'Int', );
-    has 'visible' => ( is => 'rw', isa => 'Bool',  );
-    has 'min' => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
-    has 'max' => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
+    has 'name'        => ( is => 'rw', isa => enum(['x_axis', 'y_axis', 'y_axis_right']), required => 1 );
+    has 'labels'      => ( is => 'rw', isa => 'Chart.OFC2.Labels', coerce  => 1);
+    has 'stroke'      => ( is => 'rw', isa => 'Int', );
+    has 'colour'      => ( is => 'rw', isa => 'Str',  );
+    has 'offset'      => ( is => 'rw', isa => 'Bool', );
+    has 'grid_colour' => ( is => 'rw', isa => 'Str', );
+    has '3d'          => ( is => 'rw', isa => 'Bool', );
+    has 'steps'       => ( is => 'rw', isa => 'Int', );
+    has 'visible'     => ( is => 'rw', isa => 'Bool',  );
+    has 'min'         => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
+    has 'max'         => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
 
 =cut
 
-subtype 'Chart-OFC2-YAxis'
+subtype 'Chart.OFC2.YAxis'
     => as 'Object'
     => where { $_[0]->isa('Chart::OFC2::YAxis') };
-subtype 'Chart-OFC2-XAxis' 
+subtype 'Chart.OFC2.XAxis' 
     => as 'Object'
     => where { $_[0]->isa('Chart::OFC2::XAxis') };
 
-has 'name'   => ( is => 'rw', isa => enum(['x_axis', 'y_axis', 'y_axis_right']), required => 1 );
-has 'labels' => ( is => 'rw', isa => 'Chart-OFC2-Labels', coerce  => 1);
-has 'stroke' => ( is => 'rw', isa => 'Int', );
-has 'color' => ( is => 'rw', isa => 'Str',  );
-has 'offset' => ( is => 'rw', isa => 'Bool', );
-has 'grid_color' => ( is => 'rw', isa => 'Str', );
-has '3d' => ( is => 'rw', isa => 'Bool', );
-has 'steps' => ( is => 'rw', isa => 'Int', );
-has 'visible' => ( is => 'rw', isa => 'Bool',  );
-has 'min' => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
-has 'max' => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
+coerce 'Chart.OFC2.XAxis'
+    => from 'HashRef'
+    => via { Chart::OFC2::XAxis->new($_) };
+coerce 'Chart.OFC2.YAxis'
+    => from 'HashRef'
+    => via { Chart::OFC2::YAxis->new($_) };
+
+has 'name'        => ( is => 'rw', isa => enum(['x_axis', 'y_axis', 'y_axis_right']), required => 1 );
+has 'labels'      => ( is => 'rw', isa => 'Chart.OFC2.Labels', coerce  => 1);
+has 'stroke'      => ( is => 'rw', isa => 'Int', );
+has 'colour'      => ( is => 'rw', isa => 'Str',  );
+has 'offset'      => ( is => 'rw', isa => 'Bool', );
+has 'grid_colour' => ( is => 'rw', isa => 'Str', );
+has '3d'          => ( is => 'rw', isa => 'Bool', );
+has 'steps'       => ( is => 'rw', isa => 'Chart.OFC2.NaturalInt', );
+has 'visible'     => ( is => 'rw', isa => 'Bool',  );
+has 'min'         => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
+has 'max'         => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
 
 =head1 METHODS
 
@@ -98,6 +107,7 @@ X axis object.
 
 package Chart::OFC2::XAxis;
 use Moose;
+use MooseX::StrictConstructor;
 
 extends 'Chart::OFC2::Axis';
 
@@ -124,6 +134,7 @@ y axis object.
 
 package Chart::OFC2::YAxis;
 use Moose;
+use MooseX::StrictConstructor;
 
 extends 'Chart::OFC2::Axis';
 
@@ -151,6 +162,7 @@ y axis on the right side object.
 package Chart::OFC2::YAxisRight;
 
 use Moose;
+use MooseX::StrictConstructor;
 
 extends 'Chart::OFC2::YAxis';
 
